@@ -1,41 +1,17 @@
-from typing import Any, Optional, Type, Union
-from graia.broadcast import Broadcast
-from graia.broadcast.entities.exectarget import ExecTarget
-from graia.broadcast.priority import Priority
-from graia.broadcast.entities.event import BaseEvent
-from abc import ABCMeta, abstractmethod
-from graia.broadcast.utilles import run_always_await
-from graia.broadcast.entities.signatures import Force, RemoveMe
-from graia.broadcast.exceptions import PropagationCancelled
 import asyncio
+from asyncio.futures import Future
+from typing import Any, Optional, Type, Union
+
+from graia.broadcast import Broadcast
+from graia.broadcast.entities.event import Dispatchable
+from graia.broadcast.entities.exectarget import ExecTarget
+from graia.broadcast.entities.signatures import RemoveMe
+from graia.broadcast.exceptions import PropagationCancelled
+from graia.broadcast.priority import Priority
+
 from .waiter import Waiter
 
 
-class ActiveStats:
-    def __init__(self) -> None:
-        self.actived = False
-
-    def get(self) -> bool:
-        return self.actived
-
-    def set(self) -> bool:
-        self.actived = True
-        return True
-
-
-class Value:
-    value: Any
-
-    def __init__(self) -> None:
-        self.value = None
-
-    def getValue(self) -> Any:
-        return self.value
-
-    def setValue(self, value) -> None:
-        self.value = value
-
-
 class InterruptControl:
     """即中断控制, 主要是用于监听器/其他地方进行对符合特定要求的事件的捕获, 并返回事件.
 
@@ -64,38 +40,31 @@ class InterruptControl:
         Returns:
             Any: 通常这个值由中断本身定义并返回.
         """
-        local_event = asyncio.Event()
-        value_container = Value()
-        active_stat = ActiveStats()
+        future = asyncio.get_running_loop().create_future()
 
-        listener_callables = []
+        listeners = set()
         for event_type in waiter.listening_events:
             listener_callable = self.leader_listener_generator(
-                local_event, waiter, event_type, value_container, active_stat
+                waiter, event_type, future
             )
             self.broadcast.receiver(
                 event_type, priority=priority or waiter.priority, **kwargs
             )(listener_callable)
-            listener_callables.append(listener_callable)
+            listener = self.broadcast.getListener(listener_callable)
+            listeners.add(listener)
 
         try:
-            await local_event.wait()
+            return await future
         finally:  # 删除 Listener
-            if not local_event.is_set() or not active_stat.get():
-                for i in listener_callables:
-                    self.broadcast.removeListener(self.broadcast.getListener(i))
-        return value_container.getValue()
+            if not future.done():
+                for i in listeners:
+                    self.broadcast.removeListener(i)
 
     def leader_listener_generator(
-        self,
-        event_lock: asyncio.Event,
-        waiter: Waiter,
-        event_type: Type[BaseEvent],
-        value_container: Value,
-        active_stat: ActiveStats,
+        self, waiter: Waiter, event_type: Type[Dispatchable], future: Future
     ):
         async def inside_listener(event: event_type):
-            if active_stat.get():
+            if future.done():
                 return RemoveMe()
 
             result = await self.broadcast.Executor(
@@ -103,15 +72,12 @@ class InterruptControl:
                     callable=waiter.detected_event,
                     inline_dispatchers=waiter.using_dispatchers,
                     headless_decorators=waiter.using_decorators,
-                    enable_internal_access=waiter.enable_internal_access,
                 ),
                 event=event,
             )
 
             if result is not None:
-                active_stat.set()
-                event_lock.set()
-                value_container.setValue(result)
+                future.set_result(result)
                 if not waiter.block_propagation:
                     return RemoveMe()
                 raise PropagationCancelled()
